The "movG" Class Represents Objects From A Moving Grid Adjustment Using A Designed Grid
1.1
Objects can be created by calls of the form new("movG", ...) or
by a call to function movingGrid.
movingMeanMap:Object of class "matrix" for the
moving mean of the cell in the ith row and jth column.
row:Object of class "integer" for the row subscripts.
col:Object of class "integer" for the column subscripts.
observedPhe:Object of class "numeric" for the
observed phenotypic values.
adjustedPhe:Object of class "numeric" for the
adjusted phenotypic values.
movingMean:Object of class "numeric" for the
moving means.
nValues:Object of class "integer" for the
number of non-NA values used for calculating the moving mean.
adjModel:Object of class "lm" for the
model used for covariate adjustment.
correlation:Object of class "numeric" for the
coefficient of correlation between the moving means and the
observed phenotypic values.
maxValues:Object of class "integer" for the
maximum number of values possible given the design of the grid or
the number of nearest neighbors.
FunCall:Object of class "call" for the
function call.
signature(object = "movG"): extract all
relevant information on each entry from the object
signature(object = "movG"): extract only
the moving means from the object
signature(object = "movG"): extract only the
adjusted phenotypical values
signature(object = "movG"): extract the
residuals from the model for calculation of the regression coefficient
signature(object = "movG"): show some
summary statistics and informations
signature(object = "movG"): same as show, but
with a list of the summarized values invisibly returned
Frank Technow
movingGrid