mvngGrAd-package: R Package mvngGrAd: Moving Grid Adjustment In Plant Breeding Field Trials
Description
The mvngGrAd package allows to perform a moving grid
adjustment in plant breeding
field trials. Please see the
included vignette for a more detailed description of the package and the
rational behind moving grid adjustment.Details
ll{
Package: mvngGrAd
Type: Package
Version: 0.1.4
Date: 2014-12-28
License: GNU General Public License Version 2, June 1991
LazyLoad: no
}
The main function, movingGrid, performs the adjustment with a
user designed grid. The function sketchGrid helps with designing
the grid by plotting its shape. The functions fitted,
movingMean and entryData are convenience functions to
extract the most relevant information from the object created by
movingGrid. The package defines one new class, movG, and
provides methods for it for the functions, movingMean,
entryData, fitted, summary, show and
residuals.